# no code
## no critic: TestingAndDebugging::RequireUseStrict
package TableDataBundle::Perl::CPAN::Release::Static::Older;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2022-02-18'; # DATE
our $DIST = 'TableDataBundle-Perl-CPAN-Release-Static-Older'; # DIST
our $VERSION = '20220218.0'; # VERSION

1;
# ABSTRACT: Collection of TableData:: modules that contain older CPAN releases data

__END__

=pod

=encoding UTF-8

=head1 NAME

TableDataBundle::Perl::CPAN::Release::Static::Older - Collection of TableData:: modules that contain older CPAN releases data

=head1 VERSION

This document describes version 20220218.0 of TableDataBundle::Perl::CPAN::Release::Static::Older (from Perl distribution TableDataBundle-Perl-CPAN-Release-Static-Older), released on 2022-02-18.

=head1 DESCRIPTION

This distribution contains the following L<TableData>:: modules:

=over

=item * L<TableData::Perl::CPAN::Release::Static::1995>

=item * L<TableData::Perl::CPAN::Release::Static::1996>

=item * L<TableData::Perl::CPAN::Release::Static::1997>

=item * L<TableData::Perl::CPAN::Release::Static::1998>

=item * L<TableData::Perl::CPAN::Release::Static::1999>

=item * L<TableData::Perl::CPAN::Release::Static::2000>

=item * L<TableData::Perl::CPAN::Release::Static::2001>

=item * L<TableData::Perl::CPAN::Release::Static::2002>

=item * L<TableData::Perl::CPAN::Release::Static::2003>

=item * L<TableData::Perl::CPAN::Release::Static::2004>

=item * L<TableData::Perl::CPAN::Release::Static::2005>

=item * L<TableData::Perl::CPAN::Release::Static::2006>

=item * L<TableData::Perl::CPAN::Release::Static::2007>

=item * L<TableData::Perl::CPAN::Release::Static::2008>

=item * L<TableData::Perl::CPAN::Release::Static::2009>

=item * L<TableData::Perl::CPAN::Release::Static::2010>

=item * L<TableData::Perl::CPAN::Release::Static::2011>

=item * L<TableData::Perl::CPAN::Release::Static::2012>

=item * L<TableData::Perl::CPAN::Release::Static::2013>

=item * L<TableData::Perl::CPAN::Release::Static::2014>

=item * L<TableData::Perl::CPAN::Release::Static::2015>

=item * L<TableData::Perl::CPAN::Release::Static::2016>

=item * L<TableData::Perl::CPAN::Release::Static::2017>

=item * L<TableData::Perl::CPAN::Release::Static::2018>

=item * L<TableData::Perl::CPAN::Release::Static::2019>

=item * L<TableData::Perl::CPAN::Release::Static::2020>

=item * L<TableData::Perl::CPAN::Release::Static::2021>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/TableDataBundle-Perl-CPAN-Release-Static-Older>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-TableDataBundle-Perl-CPAN-Release-Static-Older>.

=head1 SEE ALSO

L<TableData>

L<TableDataBundle::Perl::CPAN::Release>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 CONTRIBUTING


To contribute, you can send patches by email/via RT, or send pull requests on
GitHub.

Most of the time, you don't need to build the distribution yourself. You can
simply modify the code, then test via:

 % prove -l

If you want to build the distribution (e.g. to try to install it locally on your
system), you can install L<Dist::Zilla>,
L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
beyond that are considered a bug and can be reported to me.

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2022, 2021 by perlancar <perlancar@cpan.org>.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=TableDataBundle-Perl-CPAN-Release-Static-Older>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=cut
